@@ -117,13 +117,14 @@ class Lightning(object):
         Enable a local mode.
 
         Data is handled locally and embedded via templates.
+        Does not require a running Lightning server.
         Useful for notebooks, and can be used offline.
         """
         self.local_enabled = True
 
     def disable_local(self):
         """
-        Disable local mode
+        Disable local mode.
         """
         self.local_enabled = False
 
@@ -194,34 +195,4 @@ class Lightning(object):
         display(HTML(t))
 
     def startup_message(self):
-        print("Lightning initialized")
-
-    def plot(self, data=None, type=None):
-        """
-        Generic plotting function.
-
-        Provide an arbtirary data object as a dictionary, and a plot type as a string.
-        The data dictionary will be passed directly to the plot, without any parsing or formatting,
-        so make sure it is of the appropriate for your visualization
-        (e.g. {"series": [1,2,3]} for a "line" visualization).
-
-        Most useful when providing data to custom visualizations, as opposed to the included plot types
-        (e.g. lightning.scatter, lightning.line, etc.) which do automatic parsing and formatting.
-
-        Parameters
-        ----------
-        data : dict
-            Dictionary with data to plot
-
-        type : str
-            Name of plot (e.g. 'line' or 'scatter')
-        """
-
-        from .types.plots import Generic
-
-        if not hasattr(self, 'session'):
-            self.create_session()
-        
-        viz = Generic._baseplot(self.session, type, data)
-        self.session.visualizations.append(viz)
-        return viz
\ No newline at end of file
+        print("Lightning initialized")
\ No newline at end of file
