@@ -5,10 +5,37 @@ from lightning.types.utils import array_to_lines, vecs_to_points, \
 
 
 @viztype
-class Generic(Base):
+class Plot(Base):
+
+    _name = 'plot'
+    _options = dict(Base._options, **{
+        'type': {'default': None},
+        }
+    )
 
     @staticmethod
-    def clean(data):
+    def clean(data=None):
+        """
+        Generic plotting function.
+
+        Provide arbitrary data and options objects as dictionaries,
+        and a plot type as a string. The data and options dictionary will be passed
+        directly to the plot, without any parsing or formatting,
+        so make sure it is of the appropriate for your visualization
+        (e.g. {"series": [1,2,3]} for a "line" visualization).
+
+        Most useful when providing data to custom visualizations, as opposed
+        to the included plot types (e.g. lightning.scatter, lightning.line, etc.)
+        which do automatic parsing and formatting.
+
+        Parameters
+        ----------
+        data : dict
+            Dictionary with data to plot
+
+        type : str
+            Name of plot (e.g. 'line' or 'scatter')
+        """
         return data
 
 
@@ -213,7 +240,7 @@ class Line(Base):
     )
 
     @staticmethod
-    def clean(series, index=None, color=None, group=None, size=None, xaxis=None, yaxis=None):
+    def clean(series, index=None, color=None, group=None, thickness=None, xaxis=None, yaxis=None):
         """
         Plot one-dimensional series data as lines.
 
@@ -234,7 +261,7 @@ class Line(Base):
         group : array-like, optional, singleton or (n,)
             Single integer or array to set line colors via group assignment
 
-        size : array-like, optional, singleton or (n,)
+        thickness : array-like, optional, singleton or (n,)
             Single size or array to set line thickness
 
         xaxis : str, optional, default = None
@@ -251,7 +278,7 @@ class Line(Base):
         outdict = {'series': series}
 
         outdict = add_property(outdict, color, 'color')
-        outdict = add_property(outdict, size, 'size')
+        outdict = add_property(outdict, thickness, 'thickness')
         outdict = add_property(outdict, group, 'group')
         outdict = add_property(outdict, index, 'index')
         outdict = add_property(outdict, xaxis, 'xaxis')
@@ -480,7 +507,7 @@ class GraphBundled(Base):
     @staticmethod
     def clean(x, y, conn, labels=None, values=None, color=None, group=None, colormap=None, size=None):
         """
-        Create a node-link graph with bundled edges from spatial points and their connectivity.
+        Create a bundled node-link graph from spatial points and their connectivity.
 
         .. image:: graphbundled.png
 
@@ -568,3 +595,35 @@ class Map(Base):
         outdict = add_property(outdict, colormap, 'colormap')
 
         return outdict
+
+
+@viztype
+class Histogram(Base):
+
+    _name = 'histogram'
+    _options = dict(Base._options, **{
+        'zoom': {'default': True}
+        }
+    )
+
+    @staticmethod
+    def clean(values, bins=None):
+        """
+        Create a histogram.
+
+        .. image:: histogram.png
+
+        Parameters
+        ----------
+        values : list
+            Values to plot a histogram of
+
+        bins : number, optional
+            Number of bins to used in the histogram. If unspecified
+            will default to sqrt(len(values))
+        """
+
+        outdict = {'values': values}
+        outdict = add_property(outdict, bins, 'bins')
+
+        return outdict
\ No newline at end of file
