@@ -22,9 +22,11 @@ def check_property(prop, name, **kwargs):
         'color': check_color,
         'alpha': check_alpha,
         'size': check_size,
+        'thickness': check_thickness,
         'index': check_index,
         'coordinates': check_coordinates,
-        'colormap': check_colormap
+        'colormap': check_colormap,
+        'bins': check_bins
     }
 
     if name in checkers:
@@ -49,6 +51,9 @@ def check_coordinates(co, xy=None):
     return co
 
 
+def check_bins(b):
+    return b
+
 def check_color(c):
     """
     Check and parse color specs as either a single [r,g,b] or a list of
@@ -92,6 +97,16 @@ def check_size(s):
 
     return s
 
+def check_thickness(s):
+    """
+    Check and parse thickness specs as either a single [s] or a list of [s,s,s,...]
+    """
+
+    s = check_1d(s, "thickness")
+    if any(map(lambda d: d <= 0, s)):
+        raise Exception('Thickness cannot be 0 or negative')
+
+    return s
 
 def check_index(i):
     """
